{%if boards or open_cards or closed_cards or due_cards %}
[trello]
{%if open_boards %}
{% trans count=open_boards|length %}
- {{ count }} open board
{% pluralize %}
- {{ count }} open boards
{% endtrans %}
{% endif %}
{%if closed_boards %}
{% trans count=closed_boards|length %}
- {{ count }} closed board
{% pluralize %}
- {{ count }} closed boards
{% endtrans %}
{% endif %}
{%if open_cards %}
{% trans count=open_cards|length %}
- {{ count }} open assigned card
{% pluralize %}
- {{ count }} open assigned cards
{% endtrans %}
{% endif %}
{% if closed_cards %}
{% trans count=closed_cards|length %}
- {{ count }} closed assigned card:
{% pluralize %}
- {{ count }} closed assigned cards:
{% endtrans %}
{% for card in closed_cards %}
  + {{ card.name }}
{% endfor %}
{% endif %}
{%if due_cards %}
{% trans count=due_cards|length %}
- {{ count }} due assigned card:
{% pluralize %}
- {{ count }} due assigned cards:
{% endtrans %}
{% for card in due_cards %}
  + {{ card.name }}
{% endfor %}
{% endif %}
{% endif %}
