{% if tweets or retweets or mentions %}
[twitter]
{% if tweets %}
{% trans count=tweets|length %}
- {{ count }} tweet
{% pluralize %}
- {{ count }} tweets
{% endtrans %}
{% endif %}
{% if retweets %}
{% trans count=retweets|length %}
- {{ count }} retweet by others
{% pluralize %}
- {{ count }} retweets by others
{% endtrans %}
{% endif %}
{% if mentions %}
{% trans count=mentions|length %}
- {{ count }} mention by others
{% pluralize %}
- {{ count }} mentions by others
{% endtrans %}
{% endif %}
{% endif %}
