{% if edits %}
[mediawiki: {{ url.hostname }}]
{% trans count=edits|length %}
- {{ count }} page edit:
{% pluralize %}
- {{ count }} page edits:
{% endtrans %}
{% for page, edits in edits|groupby("title") %}
{% trans count=edits|length %}
  + {{ count }} edit on page {{ page }}
{% pluralize %}
  + {{ count }} edits on page {{ page }}
{% endtrans %}
{% endfor %}
{% endif %}
