{% if open_bugs or closed_bugs %}
[bugzilla: {{ url.hostname }}]
{% if open_bugs %}
{% trans count=open_bugs|length %}
- {{ count }} open bug
{% pluralize %}
- {{ count }} open bugs
{% endtrans %}
{% endif %}
{% if closed_bugs %}
{% trans count=closed_bugs|length %}
- {{ count }} closed bug:
{% pluralize %}
- {{ count }} closed bugs:
{% endtrans %}
{% for bug in closed_bugs %}
  + {{ bug.id }}: {{ bug.summary }}
{% endfor %}
{% endif %}
{% endif %}
