# Copyright 2013 Sascha Peilicke
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""
:mod:`rapport` -- Work report generator for the lazy
====================================================

.. automodule:: rapport
   :synopsis: Work report generator for the lazy
.. moduleauthor:: Sascha Peilicke <saschpe@gmx.de>
"""

__author__ = "Sascha Peilicke <saschpe@gmx.de>"
__version_info__ = ("0", "1", "3")
__version__ = ".".join(__version_info__)
